import requests
import logging
from requests.adapters import HTTPAdapter

logger = logging.getLogger(__name__)

MAX_THREADS = 16


class Request(requests.Session):
    def __init__(self, url, headers=None):
        super().__init__()

        # allow using up to 16 connections
        adapter = HTTPAdapter(pool_maxsize=MAX_THREADS * 2)  # should prevent connection pool exhaustion
        self.mount(url, adapter)

        self.headers.update({
            'Accept': 'application/json'
        })
        if headers:
            self.headers.update(headers)

        self.BASE_URL = url

    def do_request(self, method, endpoint, **kwargs) -> requests.Response:
        r = self.request(method, self.BASE_URL + endpoint, timeout=15, **kwargs)

        r.raise_for_status()
        return r

    def get(self, endpoint: str, **kwargs):
        return self.do_request('get', endpoint, **kwargs)

    def post(self, endpoint: str, data=None, **kwargs):
        return self.do_request('post', endpoint, data=data, **kwargs)

    def put(self, endpoint: str, **kwargs):
        return self.do_request('put', endpoint, **kwargs)

    def delete(self, endpoint: str, **kwargs):
        return self.do_request('delete', endpoint, **kwargs)


class AdminRequest(Request):
    def __init__(self, hostname, admin_username, admin_password,
                 **kwargs):
        self.username = admin_username
        url = f'{admin_username}:{admin_password}@{hostname}/'
        super().__init__('http://' + url)

    def __str__(self):
        return f'admin user: {self.username}'


class TokenRequest(Request):
    def __init__(self, hostname, token: str, **kwargs):
        self.token = token

        super().__init__(f'http://{hostname}/', {
            'Authorization': 'Bearer ' + token
        })

    def __str__(self):
        return f'token {self.token}'
