from brian_dashboard_manager.templating.helpers import get_re_peer_interface_data
import pytest


@pytest.mark.parametrize(
    "interface_type, expected",
    [
        (
            "LOGICAL",
            {
                "AGGREGATES": [
                    {
                        "interface": "xe-0/0/0.1",
                        "hostname": "mx1.dub2.ie.geant.net",
                        "alias": "DUB2 - ESNET (xe-0/0/0.1)",
                    }
                ],
                "SERVICES": [
                    {
                        "title": "mx1.dub2.ie - {} - xe-0/0/0.1 - description",
                        "interface": "xe-0/0/0.1",
                        "hostname": "mx1.dub2.ie.geant.net",
                        "has_v6": True,
                    }
                ],
            },
        ),
        (
            "PHYSICAL",
            {
                "PHYSICAL": [
                    {
                        "title": "mx1.dub2.ie - {} - xe-0/0/0.1 - description",
                        "interface": "xe-0/0/0.1",
                        "hostname": "mx1.dub2.ie.geant.net",
                    }
                ],
            },
        ),
        (
            "AGGREGATE",
            {
                "PHYSICAL": [
                    {
                        "title": "mx1.dub2.ie - {} - xe-0/0/0.1 - description",
                        "interface": "xe-0/0/0.1",
                        "hostname": "mx1.dub2.ie.geant.net",
                    }
                ],
            },
        ),
    ],
)
def test_re_peer_interface_data(interface_type, expected):
    interfaces = [
        {
            "router": "mx1.dub2.ie.geant.net",
            "name": "xe-0/0/0.1",
            "description": "description",
            "dashboards": ["RE_PEER"],
            "dashboard_info": {"name": "ESNET", "interface_type": interface_type},
            "dashboards_info": [{"name": "ESNET", "interface_type": interface_type}],
            "ipv4": ["1.1.1.1"],
            "ipv6": ["::2"],
        },
    ]

    assert get_re_peer_interface_data(interfaces) == {
        "ESNET": {"AGGREGATES": [], "SERVICES": [], "PHYSICAL": [], **expected}
    }
